#
# spec file for package python-azure-agent
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-azure-agent
Summary:        Microsoft Azure Linux Agent
License:        Apache-2.0
Group:          System/Daemons
Version:        2.2.45
Release:        lp151.2.6.1
URL:            https://github.com/Azure/WALinuxAgent
Source0:        WALinuxAgent-%{version}.tar.gz
Patch1:         agent-no-auto-update.patch
Patch6:         paa_force_py3_sle15.patch
Patch9:         paa_sudo_sle15_nopwd.patch
Patch10:        paa_use_hostnamectl.patch
BuildRequires:  dos2unix

BuildRequires:  distribution-release
BuildRequires:  openssl
%if 0%{?suse_version} < 1140
BuildRequires:  python-ordereddict
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1315
BuildRequires:  python3-devel
BuildRequires:  python3-distro
BuildRequires:  python3-mock
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  python3-xml
%else
BuildRequires:  python-devel
BuildRequires:  python-mock
BuildRequires:  python-pytest
BuildRequires:  python-setuptools
BuildRequires:  python-xml
%endif
BuildRequires:  pkgconfig(udev)
Requires:       eject
Requires:       grep
Requires:       iptables
Requires:       logrotate
%if 0%{?suse_version} < 1140
Requires:       insserv
Requires:       sysvinit
%else
Requires:       systemd
Requires:       wicked
%endif
Requires:       openssh
Requires:       openssl
Requires:       pwdutils
%if 0%{?suse_version} && 0%{?suse_version} > 1315
Requires:       python3-distro
Requires:       python3-pyasn1
Requires:       python3-xml
%else
Requires:       python-pyasn1
Requires:       python-xml
%endif
Requires:       sudo
Requires:       util-linux

# Package renamed in SLE 12, do not remove Provides, Obsolete directives
# until after SLE 12 EOL
Provides:       WALinuxAgent = %{version}
Obsoletes:      WALinuxAgent < %{version}

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description
The azure-agent supports the provisioning and running of Linux
VMs in the Microsoft Azure Public Cloud and Microsoft Azure Stack private
cloud. This package should be installed on Linux disk
images that are built to run withing the Microsoft Azure or
Microsoft Azure Stack framework.

%package test
Summary:        Unit tests
Group:          Development/Languages/Python
Requires:       %{name} == %{version}
Requires:       openssl
%if 0%{?suse_version} && 0%{?suse_version} > 1315
Requires:       python3-mock
Requires:       python3-pytest
%else
Requires:       python-mock
Requires:       python-pytest
%endif
%if 0%{?suse_version} < 1140
Requires:       python-ordereddict
%endif

%description test
Unit tests for python-azure-agent.

%prep
%setup -qn WALinuxAgent-%{version}
%patch1
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%patch6
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%patch9
%endif
%patch10

%build
%if 0%{?suse_version} && 0%{?suse_version} > 1315
python3 setup.py build
%else
python setup.py build
%endif

%install
%if 0%{?suse_version} && 0%{?suse_version} > 1315
python3 setup.py install --prefix=%{_prefix} --lnx-distro='suse' --root=%{buildroot}
%else
python setup.py install --prefix=%{_prefix} --lnx-distro='suse' --root=%{buildroot}
%endif
%if 0%{?suse_version} > 1140
ln -s service %{buildroot}%{_sbindir}/rcwaagent
%if 0%{?suse_version} < 1230
    mkdir -p %{buildroot}/%{_unitdir}
    mv %{buildroot}/usr/lib/systemd/system/* %{buildroot}/%{_unitdir}
    rm -rf %{buildroot}/usr/lib/systemd
%endif
%else
### rc symlink
ln -s ../..%{_initddir}/waagent %{buildroot}%{_sbindir}/rcwaagent
%endif
### udev rules
%if 0%{?suse_version} < 1230
mkdir -p %{buildroot}/lib/udev/rules.d
mv %{buildroot}%{_sysconfdir}/udev/rules.d/* %{buildroot}/lib/udev/rules.d/
%else
mkdir -p %{buildroot}/usr/lib/udev/rules.d
mv %{buildroot}%{_sysconfdir}/udev/rules.d/* %{buildroot}/usr/lib/udev/rules.d/
%endif
### log file ghost
mkdir -p  %{buildroot}/%{_localstatedir}/log
touch %{buildroot}/%{_localstatedir}/log/waagent.log
### permissinon fixes
chmod +x %{buildroot}/%{_sbindir}/waagent2.0
### naming issues
mv %{buildroot}/%{_sysconfdir}/logrotate.d/waagent.logrotate %{buildroot}/%{_sysconfdir}/logrotate.d/waagent

# install tests
%if 0%{?suse_version} && 0%{?suse_version} > 1315
cp -r tests %{buildroot}/%{python3_sitelib}/azurelinuxagent
%else
cp -r tests %{buildroot}/%{python_sitelib}/azurelinuxagent
%endif

%pre
%if 0%{?suse_version} > 1140
    %service_add_pre waagent.service
%endif

%post
%if 0%{?suse_version} > 1140
    %service_add_post waagent.service
%endif

%preun
%if 0%{?suse_version} > 1140
    %service_del_preun waagent.service
%else
    %stop_on_removal waagent
%endif

%postun
%restart_on_update waagent
%if 0%{?suse_version} > 1140
    %service_del_postun waagent.service
%else
    %insserv_cleanup
%endif

%files
%defattr(0644,root,root,0755)
%doc Changelog NOTICE README.md
%license LICENSE.txt 
%{_sbindir}/rcwaagent
%attr(0755,root,root) %{_sbindir}/waagent
%attr(0755,root,root) %{_sbindir}/waagent2.0
%config(noreplace) %{_sysconfdir}/logrotate.d/waagent
%config(noreplace) %{_sysconfdir}/waagent.conf
%ghost %{_localstatedir}/log/waagent.log
%if 0%{?suse_version} > 1140
%{_unitdir}/waagent.service
%else
%attr(0755,root,root) %{_initddir}/waagent
%endif
%if 0%{?suse_version} < 1230
/lib/udev/rules.d/66-azure-storage.rules
/lib/udev/rules.d/99-azure-product-uuid.rules
%else
/usr//lib/udev/rules.d/66-azure-storage.rules
/usr/lib/udev/rules.d/99-azure-product-uuid.rules
%endif
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%dir %{python3_sitelib}/azurelinuxagent
%{python3_sitelib}
%exclude %{python3_sitelib}/azurelinuxagent/tests
%else
%dir %{python_sitelib}/azurelinuxagent
%{python_sitelib}
%exclude %{python_sitelib}/azurelinuxagent/tests
%endif

%files test
%defattr(0644,root,root,0755)
%if 0%{?suse_version} && 0%{?suse_version} > 1315
%{python3_sitelib}/azurelinuxagent/tests
%else
%{python_sitelib}/azurelinuxagent/tests
%endif

%changelog
* Tue Mar 24 2020 Robert Schweikert <rjschwei@suse.com>
- Add paa_use_hostnamectl.patch (bsc#1167601, bsc#1167602)
  + Set the hostname using hostnamectl to ensure setting is
    properly applied
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through -mini flavors.
* Thu Dec  5 2019 Robert Schweikert <rjschwei@suse.com>
- Update to version 2.2.45 (jsc#ECO-80)
  + Remove paa_cve_2019-0804.patch, included upstream
  + Add support for Gen2 VM resource disks
  + Use alternate systemd detection
  + Fix /proc/net/route requirement that causes errors on FreeBSD
  + Add cloud-init auto-detect to prevent multiple provisioning mechanisms
    from relying on configuration for coordination
  + Disable cgroups when daemon is setup incorrectly
  + Remove upgrade extension loop for the same goal state
  + Add container id for extension telemetry events
  + Be more exact when detecting IMDS service health
  + Changing add_event to start sending missing fields
- From 2.2.44
  + Remove outdated extension ZIP packages
  + Improved error handling when starting extensions using systemd
  + Reduce provisioning time of some custom images
  + Improve the handling of extension download errors
  + New API for extension authors to handle errors during extension update
  + Fix handling of errors in calls to openssl
  + Improve logic to determine current distro
  + Reduce verbosity of several logging statements
- From 2.2.42
  + Poll for artifact blob, addresses goal state procesing issue
- From 2.2.41
  + Rewriting the mechanism to start the extension using systemd-run for
    systems using systemd for managing
  + Refactoring of resource monitoring framework using cgroup for both
    systemd and non-systemd approaches [#1530, #1534]
  + Telemetry pipeline for resource monitoring data
- From 2.2.40
  + Fixed tracking of memory/cpu usage
  + Do not prevent extensions from running if setting up cgroups fails
  + Enable systemd-aware deprovisioning on all versions >= 18.04
  + Add systemd support for Debian Jessie, Stretch, and Buster
  + Support for Linux Openwrt
- From 2.2.38
  + Fix CVE-2019-0804
  + Add fixes for handling swap file and other nit fixes
- From 2.2.37
  + Improves re-try logic to handle errors while downloading extensions
* Thu Mar  7 2019 Robert Schweikert <rjschwei@suse.com>
- Add paa_cve_2019-0804.patch (bsc#1127838)
  - An issue with swapfile handling in the agent creates a data leak situation
    that exposes system memory data.
* Thu Feb  7 2019 Robert Schweikert <rjschwei@suse.com>
- Update to 2.2.36 (bsc#1119542)
  - Remove, included upstream
    + paa_fix_driver_install_detect.patch
    + paa_rdma_install_proper_driver.patch
    + 0001-Obtain-platform-information-in-Python-version-depend.patch
    + 0001-Detect-openSUSE-and-SLES.patch
    + 0001-Handle-the-disapperance-of-net-tools.patch
    + 0001-Properly-detect-SLES-15-for-rdma-support.patch
  - Forward port agent-no-auto-update.patch
  - [#1451] Do not utf-8 encode telemetry messages
- From 2.2.35
  + [#1434] Use files instead of pipes to capture stdout/stderr
  + [#1431] Prevent multiple downloads of zips
  + [#1418] Add main module to Python's egg
  + [#1416] Fix UTF-8 encoding for telemetry payload
  + [#1408] Honor the 'no_proxy' flag
  + [#1391, #1401, #1441] Azure Stack improvements
  + [#1384] Write status file in WALinuxAgent lib folder
  + [#1375] Add support for Redhat
  + [#1373] Handle different kernel builds on SUSE Linux Enterprise
  + [#1365, #1385, #1389] Fixes for RDMA
- From 2.2.34
  + [#1397] Send events when extensions fail to complete operation
  + [#1394/#1366] Fix the threshold telemetry issue
  + [#1298] Implementing extension sequencing in azure Linux agent
  + [#1340] Allow Clear Linux detection in python2 and python3
  + [#1345] FreeBSD swap issues fix (#1144)
  + [#1349] Use append_file in Redhat6xOSUtil.openssl_to_openssh()
  + [#1355] Ensure 'value' for authorized ssh keys end in "\n"
  + [#1361] Remove main module
- From 2.2.32
  + [#1325] Enable cgroups by default on all distros
  + [#1327, #1347] Allow enforcing of cgroups limits
  + [#1337] Allow configuration for cgroups
  + [#1333] Add support for NSBSD
  + [#1319] Stream extension downloads to disk
    (do not buffer the download in memory)
  + [#1303] Fix to support custom DNS servers
  + [#1306] Log extension stdout and stderr
  + [#1302] Better of cloud-init configuration during deprovisioning
  + [#1295] Fix to report the correct extension error code
  + [#1289] Allow disabling the agent or extensions
  + [#1290] Use the "ip route" command instead of the "route" comand
    during network configuration
  + [#1281] Delete JIT accounts
  + [#1234] Fix for reading KVP values from host
  + [#1287] Add UDEV rule in azure disk encryption
- From 2.2.31
  Upstream version jump
  + [#1196] Health store integration
  + [#1199] CGroups support
  + [#1194] Use host for status reporting
  + [#1188] Fix for sentinel and signal handlers
  + [#1182] Telemetry updates
  + [#1171] Add support for JIT
  + [#1164] Fix for name resolution in Ubuntu 18.04
  + [#1154] Set connection close header
  + [#1143] Remove extension packages after extraction
- From 2.2.26
  + Update Debian specific configuration and setup.
- From 2.2.25
  + Upstream version jump
  + Revert extension manifest caching to prevent downgrade issues.
- From 2.2.20
  + This is a hotfix release for #945, details and mitigation are available
    in the wiki.
- From 2.2.29
  + [#929] wire.py#update_goal_state does not handle out-of-date
    GoalState errors
  + [#908] Set Files to 0400 in /var/lib/waagent
  + [#906] Hardcoded value for sshd's ClientAliveInterval (180)
  + [#899] Improve HeartBeat Event
  + [#898] Send dummy status if extension fails to write a #.status file
  + [#897] 'Target handler state' wall of errors
  + [#896] End of Line Comments are Not Supported nor Handled
  + [#891] Create a Telemetry Event to Track Custom Data Execution
  + [#884] Cleanup Old Goal State and Extension Cache
  + [#876] The agent should use a scaling back-off when retrying HTTP requests
  + [#869] The agent should report OS information in the correct JSON format.
  + [#822] Update docs
* Wed Jun  6 2018 rjschwei@suse.com
- Remove paa_up_only_to_push_hostname.patch
  + Turns out the issue was a kernel bug and while ifdown ifup sequence to
    bounce the hostname to the DHCP server is overkill we do not
    want to carry a "cosmetic" patch
* Tue Jun  5 2018 rjschwei@suse.com
- Add paa_up_only_to_push_hostname.patch (bsc#1094420)
* Thu May 10 2018 rjschwei@suse.com
- Add 0001-Handle-the-disapperance-of-net-tools.patch (bsc#1092831)
  + Switch to using "ip route" command
- Add paa_sudo_sle15_nopwd.patch
  + Work around issue where SLE 15 will not accept the user password when
    using sudo, cause unknown, needed to time constraints w.r.t. release
- Add 0001-Properly-detect-SLES-15-for-rdma-support.patch
  + Properly detect SLES 15 for RDMA support
* Mon Apr  2 2018 rjschwei@suse.com
- Add 0001-Detect-openSUSE-and-SLES.patch (bsc#1087764)
  + Properly detect SLES 15 and openSUSE Leap 15 in Python 3
* Tue Mar 20 2018 rjschwei@suse.com
- Update paa_force_py3_sle15.patch (bsc#1061584)
  + Another reference to python, which points to python2
* Tue Feb 27 2018 rjschwei@suse.com
- Add paa_force_py3_sle15.patch
  + Force use of Python 3 for SLE 15 and later
* Wed Feb 21 2018 rjschwei@suse.com
- Modify 0001-Obtain-platform-information-in-Python-version-depend.patch to
  reflect agreed upon solution with upstream
* Thu Feb  8 2018 rjschwei@suse.com
- Add 0001-Obtain-platform-information-in-Python-version-depend.patch
  to fix build on distribution with Python 3.6 and later (boo#997614)
* Fri Jan  5 2018 rjschwei@suse.com
- Fix RDMA driver package version install issue (bsc#1074865)
  + Added paa_rdma_install_proper_driver.patch
* Thu Oct 12 2017 rjschwei@suse.com
- Update to version 2.2.18
  + [#868] Fix for sudoer update
  + [#886] Agent should not update outside of goal state
  + [#889] Firewall removal should not retry
  - Fixes issues introduces with 2.2.17
* Tue Oct  3 2017 dimstar@opensuse.org
- BuildRequire distribution-release instead of
  openSUSE/sles-release.
* Wed Sep 20 2017 rjschwei@suse.com
- Fix typo in dependency
* Sat Sep 16 2017 rjschwei@suse.com
- Update to version 2.2.17 (bsc#1058974, bsc#1058975)
  + Remove paa_noref_local_install.patch, included upstream
  + Setup build for Python 3 for distros > SLE 12
  + [#879] -- OS.EnableFirewall=y breaks load balanced sets probing
- From 2.2.16
  + [#865] -- The agent should retry ETIMEDOUT (110) IOErrors
- From 2.2.15
  + [#783] -- The agent fails to use the standard Linux environment variables
    for HTTP proxy
  + [#784] -- Adjust http retry and logging
  + [#786] -- Add Provisioning.SshHostKeyPairType=auto to support ssh-keygen -A
  + [#791] -- Prevent bloating sudoers waagent when agent has problem
  + [#792] -- Clearlinux distro_name does not match
  + [#796] -- Accommodate new Clear Linux distro string in os-release
  + [#798] -- Support Ubuntu RDMA driver update
  + [#800] -- HostGAPlugin still use proxy while auto-updating
  + [#801] -- Agent fails to clean-up PID files
  + [#807] -- The agent should not emit duplicate events
  + [#808] -- The agent should more gracefully handle out-of-space disk
    errors (IOError 28)
  + [#811] -- Comments inline in /etc/waagent.conf cause config to not be read
  + [#812] -- Agent fails and isn't recoverable if an extension's log
    directory is not present anymore
  + [#823] -- Show config options in use
  + [#830] -- Ensure VM identifier is properly ordered
  + [#845] -- ')' is missed in show-configuration
  + [#850] -- Cannot get to state 'Running' with Provisioning.Enabled=n
* Fri Sep  8 2017 rjschwei@suse.com
- Add paa_fix_driver_install_detect.patch (bsc#1057888)
  + Avoid the driver from re-installing if the same version is already
    installed, this avoids an enless reboot loop
* Mon Jul 24 2017 rjschwei@suse.com
- Add paa_noref_local_install.patch (bsc#1050229)
  + Do not refresh the repos when we install the local RDMA kmp,
    repo access has already failed, no need to try again
* Sun Jul 23 2017 rjschwei@suse.com
- Update to version 2.2.14 (bsc#1050000)
  + [#777] -- Deprovisioning when VM identifier changes is too aggressive
  + [#769] -- HostGAPlugin requests should never go through proxy
  + [#764] -- waagent -configuration-path:/path -start not take effect
  + [#761] -- MetadataProtocol has no client object
  + [#757] -- deprovision is executed even if input 'n'
  + [#754] -- /etc/resolv.conf is removed if create a VM base on
    an specialized image
  + [#746] -- Agent WALinuxAgent-2.2.12 is blacklisted - skipping download
  + [#740] -- Duplicate logging on RHEL/CentOS
* Sun Jul 23 2017 rjschwei@suse.com
- Remove timeout udev rules (bsc#1049480)
  + 99-azure-timeout.rules
  + Rule is broken
  + Timeout is being set by the eagent code
* Tue Jun 13 2017 rjschwei@suse.com
- Modify dependencies, systemd is runtime, not build
* Thu Jun  8 2017 rjschwei@suse.com
- Update to version 2.2.13 (bsc#1042202, bsc#1042203)
  + [#712] Initial support for OpenBSD
  + [#730] Archlinux documentation
  + [#743] Fix for FreeBSD resource disk discovery
  + [#748] Fix for host plugin response encoding
  + [#750] Fix for GAiA public key handling
  + [#751] Fix for host plugin channel initialization
  + [#752] Fix for AzureStack protocol error handling
  + [#753] Removal of iptables rules from AzureStack protocol
- From 2.2.12
  + [#711] -- There are too many log print to /var/log/waagent.log
  + [#714] -- Questionable split call in common/conf.py
  + [#717] -- Remove extension logs during deprovision
  + [#720] -- Reset of RDMA drivers not taking effect
  + [#721] -- WALA deprovision process not clean up all cloudinit files
  + [#724] -- Location of configuration file should be editable issue
  + [#725] -- v2.2.11 can throw unexpected exceptions on provisioned VMs
  + [#727] -- v2.2.11 cannot update status for RDFE VMs
- From 2.2.11
  + [#463] Ensure the transport certificate expires in no more than two
    years enhancement
  + [#470] Emit goal state processing performance metrics enhancement
  + [#518] Align with the Azure Stack protocol enhancement
  + [#531] Location of configuration file should be editable feature request
  + [#604] v2.2.x - Need new OS.SshDir in waagent.conf feature request
  + [#631] Will "waagent -deprovision[+user]" wipe the cloud-init data?
    feature request
  + [#668] Agent continuously logs error on FIPS compliant server
  + [#679] Enable auto-update for AzureStack feature request
  + [#682] Default route is not added if it already exists cla-not-required
  + [#684] mkfs options out of order
  + [#685] Change option order for mkfs. Alpine is being picky
  + [#686] Use of hostnameclt causes hostname rename lowercase for RHEL 7.x
  + [#687] Enable customer-supported cloud-init
  + [#688] Agent should purge /var/lib/waagent/events if it gets full
  + [#689] Remove superseded extension folders / zip files
  + [#693] Agent should remove unused extension directories and zip
    files enhancement
  + [#694] Agent should not issue an HTTP HEAD to determine status blob
    type enhancement
  + [#695] Ensure all udev rules are copied in Ubuntu cla-not-required
  + [#699] [2.2.10] Some questions about Extension clean up
  + [#701] Reduce polling time for extension processing
  + [#706] Provision Event is not Fired if Customer Forgets to Deprovision VM
* Fri Apr 21 2017 rjschwei@suse.com
- Update to version 2.2.10 (bsc#1035418, bsc#1035419)
  + [#675] Clean up extension directories
  + [#673] Provisioning logging improvements
  + [#674] Override decode custom data
  + [#670] Add Arch distro support
- From version 2.2.9
  + [#665] Networking logging cleanup
  + [#666] Keygen logging cleanup
  + [#667] Reduce the monitoring loop wait time
- From version 2.2.8
  + [#649] Improve host plugin failure handling
  + [#647] Add telemetry for put status failures
  + [#646] Improve extension handler logging
  + [#645] Reduce guest agent update logging
  + [#644] Add basic 32-bit support to interface detection
  + [#641] Better heartbeat exception handling
  + [#640] Better unhandled exception logging
  + [#638] Improve NSG state management
  + [#637] Better handling and cleanup of old events
  + [#635] Pass environment variables to subprocess
  + [#634] Improve RDMA package matching
  + [#629] Better handling of resource disk mounting
  + [#624] Data disks udev rule
  + [#614] Add support for EulerOS
- From version 2.2.7
  + [#625] Enabled PageBlob support through HostGAPlugin
* Mon Mar 13 2017 rjschwei@suse.com
- Update to version 2.2.6 (bsc#1029223, bsc#1029224)
  + [#611] Improve logging when interface detection fails
  + [#603] Retry when get thuimbprint fails
  + [#602] Ensure host plugin calls fail gracefully
  + [#601] Handle interface resets more gracefully
  + [#600] Wait for partition before mounting
  + [#599] Correct check for heartbeat freshness
  + [#594] Fix RDMA reboot issue
  + [#588] Changed permissions for log directory
- From 2.2.5
  + [#587] Fix potential sync issue with incarnation number and cache
- From 2.2.4
  + [#579] Extend VM health status
  + [#578] Fix FreeBSD deprovision
  + [#577] Improve mount call and logging
  + [#573] Centos 7.0 hostnamectl fix
* Fri Jan 27 2017 rjschwei@rjsdomain
- Update to version 2.2.3 (bsc#1018369)
  + NSG improvements
  + CoreOS fix
  + Debian fixes
  + Apply patch from Debian
  + Unhandled errors
  + Handle ExtensionError from decide_version
  + Correct mkfile size check
  + Add a log message when primary nic is not found
  + Add telemetry event for host plugin usage
  + Fix typo in log message
  + Prevent duplicates in sysinfo
  + Add support for Match blocks in sshd config
  + Fix the logic for agent version
  + Support offline hostname changes
  + Ensure config file is updated correctly
  + Support NetworkManager leases
  + Fix password encoding
  + Minor bug fixes
  + Fix for hostnamectl
  + RHEL-7 hostname
  + Fix password encrypting failure in python 2.*
  + Handle interrupt signal
  + Fix the issues for mounting resourcedisk
- From 2.2.2
  + Cleanup SUSE config
  + Support for F5 Networks BIG-IP
  + Fix sfdisk options
  + Fix for fetch manifest
  + Fix config options for RDMA
  + Fix issue with xfs swapon
  + Add Clear Linux distro support
  + Handle deprovisioning interruption
  + Reduce goal state logging
  + Increase polling rate
  + RHUI cleanup
  + Add restart_if function for Alpine
  + Support OnHold flag
  + Fix for decode_config
  + Azure stack certificate fix
  + Enable over-provisioning support
  + Enable host plugin scenarios
  + RDMA updates
  + sfdisk logging fix
  + Big IP updates
- From 2.2.1
  + Correct the installed version check in decide_version
* Wed Oct  5 2016 rjschwei@suse.com
- Add comment to specfile clarifying the Provides directive lifespan
* Mon Oct  3 2016 rjschwei@suse.com
- Update to version 2.2.0
  + Non linear release number jump
  + Add agent-no-auto-update.patch
  + [#361] More graceful 503 handling
  + [#364] Enforce http proxy support for calls to storage
  + [#367] Stop disabling SELinux during provisioning
  + [#377] Fix partition table race condition
  + [#387] Fix latest version selection
  + [#388] Fix extension substatus structure
  + [#389] Fix shlex related update bug in Python 2.6
  + [#391] Correct behavior of register-service
  + [#398] AzureStack fixes
  + [#400] Support xfs filesystem
  + [#404] Correct service start/restart behavior
  + [#411] Support for disabling provisioning
  + [#417] Stop spamming journal with pidof dhlient related messages
  + [#418] Add goal state processor to the version output
  + [#425] Fix walinuxagent.service Want, After
  + [#439] Ensure to load latest agents
  + [#451] Correct proxy port type
* Tue Sep 13 2016 rjschwei@suse.com
- Upstream releases a tarball WALinuxAgent-%%{version} while this is
  a reminder of days gone by, as in Windows Azure, it is less confusing
  and less work if we stay with the upstream source name vs. renaming
  the tarball.
* Mon Aug 29 2016 bear454@opensuse.org
- Update to version 2.1.6 (bsc#994592)
  + improved RDMA support
  + extension state migration
  + Alpine Linux support
  + fixes for #347, #351, #353
* Tue Aug  9 2016 rjschwei@suse.com
- Require eject (bsc#992796,bsc#992797)
* Tue Jul 26 2016 bbrunner@suse.com
- Added version to Provides: WALinuxAgent
* Mon Jul 25 2016 rjschwei@suse.com
- Replace Conflicts directive with Provides, Obsoletes pair
  (bsc#990424, bsc#990489)
* Wed Jul 20 2016 rjschwei@suse.com
- Update to version 2.1.5 (bsc#989789)
  + Remove 99-azure-product-uuid.rules included from upstream
  + Remove python-azure-agent-setup.diff no longer needed
  + Remove python-azure-agent-disable-test-check-pid.diff
  + Disable tests
  - Test have been re-written such that they are expected to run in
    Azure, since we build the package in the build service 95%% fail
  + goal state processing extension
  + multi-nic improvements
  + Fix failed to mount Resource Disk #145
  + Fix PID file not updating on service restart #141
  + Fix libglibmm-2.4-1c2a dependency #133
  + Fix Creating a swap file takes too long #116
  + Fix ERROR:unicode argument without an encoding occured creating
    /var/lib/waagent/CustomData #187
  + Fix Should evaluate ssh pub key file before using it #169
  + Fix waagent fails to deploy SSH key on CentOS 7 #104
  + Fix Creating a swapfile using dd is extremely slow, please use
    fallocate on Linux #127
  + Fix ERROR:Unable to fetch Bundle URI from manifest for
    Microsoft.OSTCExtensions.LinuxDiagnostic v 2.3.4 #163
  + Fix Incorrect host route set for 168.63.129.16 on machines with
    multiple NICs (CentOS 7) #190
  + agent list trim fix
  + telemetry improvements
  + signal forwarding fix
  + self-update bug-fixes
  + poll timeout fix
  + RDMA updates
  + telemetry updates
  + use dhcp cache for CentOS
  + output buffering fix
  + rdma config files
  + sigterm forwarding
  + reduced log verbosity
  + extension manager self-update
  + multi-nic improvements
  + scvmm fixes
* Wed Jul 13 2016 rjschwei@suse.com
- Do not conflict with NetworkManager (bsc#988743)
  + we want to allow users to install the WE pattern in Azure. This is
    not possible if python-azure-agent conflicts with NetworkManager.
    Testing shows that the system is still accessible if NM is installed
    after the initial boot that sets up networking. The downside, during
    image build a user could incidentally install NM and the agent and forget
    to disable NM, an instance from this image may not be reachable.
* Tue Jul 12 2016 rjschwei@suse.com
- Apply patch  python-azure-agent-disable-test-check-pid.diff with patch
  macro to appease SLES 11 build service checks
* Sat May 21 2016 rjschwei@suse.com
- Update to version 2.1.4 (bsc#980789, bsc#980790)
  + Support for FreeBSD
  + Fix a bug for internal extension version resolving
* Mon Apr 18 2016 jgleissner@suse.com
- Renamed python-azure-agent-setup.diff to python-agent-azure-setup.diff
- Package tests in sub package
* Fri Apr 15 2016 jgleissner@suse.com
- Do not package tests (python-agent-azure-setup.diff, bsc#974899)
- Enable unit tests during build
- Disable test_check_pid (fails if /proc is not available,
  python-azure-agent-disable-test-check-pid.diff)
- Do not run sed on every file (corrupts sample_ext.zip)
- Do not mark /usr/lib/udev/rules.d files as %%config
* Tue Apr  5 2016 jgleissner@suse.com
- Include in SLE 11 and SLE 12 Public Cloud modules (bnc#973427
  fate#320692)
* Thu Feb  4 2016 rjschwei@suse.com
- Update to version 2.1.3
  + Refactor distro class
  + Fixed protocol detection on Azure Stack
  + Fix extension handling issue
  + Allow overwrite existing user
  + Decode and execute custom data
* Tue Nov 10 2015 rjschwei@suse.com
- Initial build
  + Version 2.1.2.rc2
